@@ -54,11 +54,6 @@ gnutls_session initialize_tls_session()
 
    gnutls_dh_set_prime_bits(session, DH_BITS);
 
-   /* some broken clients may require this in order to connect. 
-    * This will weaken security though.
-    */
-   /* gnutls_handshake_set_rsa_pms_check( session, 1); */
-
    if (TLS_SESSION_CACHE != 0) {
       gnutls_db_set_retrieve_function(session, wrap_db_fetch);
       gnutls_db_set_remove_function(session, wrap_db_delete);
@@ -141,7 +136,7 @@ int main()
    }
 
    gnutls_certificate_set_dh_params(x509_cred, dh_params);
-   gnutls_certificate_set_rsa_params(x509_cred, rsa_params);
+   gnutls_certificate_set_rsa_export_params(x509_cred, rsa_params);
 
    /* Socket operations
     */
