@@ -1,7 +1,7 @@
 /*
  *  Copyright (C) 2000,2001,2002,2003 Nikos Mavroyanopoulos
  *
- * This file is part of GNUTLS.
+ *  This file is part of GNUTLS.
  *
  *  The GNUTLS library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public   
@@ -76,7 +76,8 @@ static const gnutls_alert_entry sup_alerts[] = {
   * See. gnutls_alert_get().
   *
   **/
-const char* gnutls_alert_get_name( gnutls_alert_level alert) {
+const char* gnutls_alert_get_name( gnutls_alert_level alert) 
+{
 const char* ret = NULL;
 
 	GNUTLS_ALERT_ID_LOOP( ret = p->desc);
