@@ -26,14 +26,14 @@
 #include <defines.h>
 
 /*
+ * They are not needed any more. You can simply enable
+ * the gnutls_log callback to get error descriptions.
+
 #define IO_DEBUG 3 // define this to check non blocking behaviour
 #define BUFFERS_DEBUG
-#define HARD_DEBUG
 #define WRITE_DEBUG
 #define READ_DEBUG
 #define HANDSHAKE_DEBUG // Prints some information on handshake 
-#define X509_DEBUG
-#define RECORD_DEBUG
 #define COMPRESSION_DEBUG
 #define DEBUG
 */
@@ -132,6 +132,8 @@ typedef enum HandshakeType { GNUTLS_HELLO_REQUEST, GNUTLS_CLIENT_HELLO, GNUTLS_S
 		     GNUTLS_CERTIFICATE_VERIFY, GNUTLS_CLIENT_KEY_EXCHANGE,
 		     GNUTLS_FINISHED=20 } HandshakeType;
 
+typedef HandshakeType gnutls_handshake_description;
+
 typedef struct {
 	opaque * data;
 	unsigned int size;
@@ -141,7 +143,6 @@ typedef struct {
 	const opaque * data;
 	unsigned int size;
 } gnutls_const_datum;
-typedef gnutls_datum gnutls_sdatum;
 
 #include <gnutls_buffer.h>
 
@@ -165,7 +166,7 @@ typedef enum gnutls_kx_algorithm { GNUTLS_KX_RSA=1, GNUTLS_KX_DHE_DSS,
 	GNUTLS_KX_RSA_EXPORT, GNUTLS_KX_SRP_RSA, GNUTLS_KX_SRP_DSS
 } gnutls_kx_algorithm;
 
-typedef enum gnutls_mac_algorithm { GNUTLS_MAC_NULL=1, GNUTLS_MAC_MD5, GNUTLS_MAC_SHA, GNUTLS_MAC_MD2 } gnutls_mac_algorithm;
+typedef enum gnutls_mac_algorithm { GNUTLS_MAC_UNKNOWN=0, GNUTLS_MAC_NULL=1, GNUTLS_MAC_MD5, GNUTLS_MAC_SHA } gnutls_mac_algorithm;
 typedef gnutls_mac_algorithm gnutls_digest_algorithm;
 
 typedef enum gnutls_compression_method { GNUTLS_COMP_NULL=1, GNUTLS_COMP_ZLIB,
@@ -225,7 +226,7 @@ typedef struct AUTH_CRED {
 
 struct GNUTLS_KEY_INT {
 	/* For DH KX */
-	gnutls_sdatum			key;
+	gnutls_datum			key;
 	MPI				KEY;
 	MPI				client_Y;
 	MPI				client_g;
@@ -441,6 +442,12 @@ typedef struct {
 	int				may_write;
 
 	int				last_alert; /* last alert received */
+
+	/* The last handshake messages sent or received.
+	 */
+	int				last_handshake_in;
+	int				last_handshake_out;
+
 	/* this is the compression method we are going to use */
 	gnutls_compression_method		compression_method;
 	/* priorities */
@@ -575,8 +582,6 @@ typedef struct {
 
 	int			cbc_protection_hack;
 
-	int			rsa_pms_check; /* 0 means enabled */
-
 	void*			user_ptr;
 
 	int			enable_private;/* non zero to
@@ -599,6 +604,12 @@ typedef struct {
 	 */
 	int			ignore_rdn_sequence;
 
+	/* This is used to set an arbitary version in the RSA
+	 * PMS secret. Can be used by clients to test whether the
+	 * server checks that version.
+	 */
+	opaque			rsa_pms_version[2];
+
 	/* If you add anything here, check _gnutls_handshake_internal_state_clear().
 	 */
 } GNUTLS_INTERNALS;
