@@ -54,13 +54,14 @@ int _gnutls_generate_master( gnutls_session session) {
 static int generate_normal_master( gnutls_session session) {
 int ret = 0;
 char random[2*TLS_RANDOM_SIZE];
+char buf[64];
 
 	memcpy(random, session->security_parameters.client_random, TLS_RANDOM_SIZE);
 	memcpy(&random[TLS_RANDOM_SIZE], session->security_parameters.server_random, TLS_RANDOM_SIZE);
 
-	_gnutls_hard_log( "INT: PREMASTER SECRET[%d]: %s\n", PREMASTER.size, _gnutls_bin2hex(PREMASTER.data, PREMASTER.size));
-	_gnutls_hard_log( "INT: CLIENT RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(session->security_parameters.client_random,32));
-	_gnutls_hard_log( "INT: SERVER RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(session->security_parameters.server_random,32));
+	_gnutls_hard_log( "INT: PREMASTER SECRET[%d]: %s\n", PREMASTER.size, _gnutls_bin2hex(PREMASTER.data, PREMASTER.size, buf, sizeof(buf)));
+	_gnutls_hard_log( "INT: CLIENT RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(session->security_parameters.client_random,32, buf, sizeof(buf)));
+	_gnutls_hard_log( "INT: SERVER RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(session->security_parameters.server_random,32, buf, sizeof(buf)));
 
 	if ( gnutls_protocol_get_version( session) == GNUTLS_SSL3) {
 		ret =
@@ -78,8 +79,8 @@ char random[2*TLS_RANDOM_SIZE];
 	_gnutls_free_datum(&PREMASTER);
 	
 	if (ret<0) return ret;
-	
-	_gnutls_hard_log( "INT: MASTER SECRET: %s\n", _gnutls_bin2hex(session->security_parameters.master_secret, TLS_MASTER_SIZE));
+
+	_gnutls_hard_log( "INT: MASTER SECRET: %s\n", _gnutls_bin2hex(session->security_parameters.master_secret, TLS_MASTER_SIZE, buf, sizeof(buf)));
 
 	return ret;
 }
@@ -356,34 +357,17 @@ int _gnutls_send_client_certificate( gnutls_session session, int again)
 	data_size = 0;
 
 	if (again == 0) {
-		if (gnutls_protocol_get_version( session) != GNUTLS_SSL3 ||
-			session->internals.selected_cert_index >= 0) {
-			/* TLS 1.0 or SSL 3.0 with a valid certificate
-			 */
-			data_size = session->internals.auth_struct->gnutls_generate_client_certificate( session, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_client_certificate( session, &data);
 
-			if (data_size < 0) {
-				gnutls_assert();
-				return data_size;
-			}
+		if (data_size < 0) {
+			gnutls_assert();
+			return data_size;
 		}
 	}
-
-	/* In the SSL 3.0 protocol we need to send a
-	 * no certificate alert instead of an
-	 * empty certificate.
-	 */
-	if (gnutls_protocol_get_version( session) == GNUTLS_SSL3 &&
-		session->internals.selected_cert_index < 0)
-	{
-		ret = gnutls_alert_send( session, GNUTLS_AL_WARNING, GNUTLS_A_SSL3_NO_CERTIFICATE);
-	} else { /* TLS 1.0 or SSL 3.0 with a valid certificate
-	          */
-		ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_CERTIFICATE_PKT);
-		gnutls_free(data);
-	}
+	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_CERTIFICATE_PKT);
+	gnutls_free(data);
 	
-	if (ret < 0) {
+	if (ret<0) {
 		gnutls_assert();
 		return ret;
 	}
