@@ -90,7 +90,7 @@ int _gnutls_x509_read_int( ASN1_TYPE node, const char* value,
 int len, result;
 size_t s_len;
 
-	len = tmpstr_size - 1;
+	len = tmpstr_size;
 	result = asn1_read_value( node, value, tmpstr, &len);
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
