@@ -30,6 +30,7 @@
 #include <gnutls_random.h>
 #include <gnutls_datum.h>
 #include <gnutls_global.h>
+#include <gnutls_num.h>
 #include "debug.h"
 
 static int _gnutls_pk_encrypt(int algo, GNUTLS_MPI * resarr, GNUTLS_MPI data, GNUTLS_MPI * pkey, int pkey_len);
@@ -85,13 +86,35 @@ int _gnutls_pkcs1_rsa_encrypt(gnutls_datum * ciphertext,
 			return GNUTLS_E_INTERNAL_ERROR;
 		}
 		
-		if ( (ret=_gnutls_get_random(ps, psize, GNUTLS_WEAK_RANDOM)) < 0) {
+		if ( (ret=_gnutls_get_random(ps, psize, GNUTLS_STRONG_RANDOM)) < 0) {
 			gnutls_assert();
 			return ret;
 		}
 		for (i = 0; i < psize; i++) {
-			if (ps[i] == 0)
-				ps[i] = 0xff;
+			opaque rnd[3];
+
+			/* Read three random bytes that will be
+			 * used to replace the zeros.
+			 */
+			if ( (ret=_gnutls_get_random( rnd, 3, GNUTLS_STRONG_RANDOM)) < 0) {
+				gnutls_assert();
+				return ret;
+			}
+			/* use non zero values for 
+			 * the first two.
+			 */
+			if (rnd[0]==0) rnd[0] = 0xaf;
+			if (rnd[1]==0) rnd[1] = 0xae;
+
+			if (ps[i] == 0) {
+				/* If the first one is zero then set it to rnd[0].
+				 * If the second one is zero then set it to rnd[1].
+				 * Otherwise add (mod 256) the two previous ones plus rnd[3], or use
+				 * rnd[1] if the value == 0.
+				 */
+				if (i<2) ps[i] = rnd[i];
+				else ps[i] = GMAX( rnd[3] + ps[i-1] + ps[i-2], rnd[1]);
+			}
 		}
 		break;
 	case 1:
@@ -168,7 +191,7 @@ int _gnutls_pkcs1_rsa_encrypt(gnutls_datum * ciphertext,
  * params is modulus, public exp., private key
  * Can decrypt block type 1 and type 2 packets.
  */
-int _gnutls_pkcs1_rsa_decrypt(gnutls_sdatum * plaintext,
+int _gnutls_pkcs1_rsa_decrypt(gnutls_datum * plaintext,
 			      gnutls_datum ciphertext, GNUTLS_MPI* params, uint params_len,
 			      uint btype)
 {
@@ -362,6 +385,8 @@ size_t tot_len = 0;
 		asn1_delete_structure(&sig);
 	}
 
+	if (sig_value->data == NULL) sig_value->size = 0;
+
 	result = asn1_der_coding( sig, "", sig_value->data, &sig_value->size, NULL);
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
@@ -640,7 +665,9 @@ int _gnutls_pk_sign(int algo, GNUTLS_MPI* data, GNUTLS_MPI hash, GNUTLS_MPI * pk
 				     "(private-key(dsa(p%m)(q%m)(g%m)(y%m)(x%m)))",
 				     pkey[0], pkey[1], pkey[2],
 				     pkey[3], pkey[4]);
-		else gnutls_assert(); 
+		else {
+			gnutls_assert(); 
+		}
 
 		break;
 	case GCRY_PK_RSA:
@@ -648,8 +675,9 @@ int _gnutls_pk_sign(int algo, GNUTLS_MPI* data, GNUTLS_MPI hash, GNUTLS_MPI * pk
 			rc = gcry_sexp_build(&s_key, NULL,
 				     "(private-key(rsa((n%m)(e%m)(d%m)(p%m)(q%m)(u%m))))",
 				     pkey[0], pkey[1], pkey[2], pkey[3], pkey[4], pkey[5]);
-		else gnutls_assert();
-
+		else {
+			gnutls_assert();
+		}
 		break;
 
 	default:
