@@ -915,10 +915,61 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[]={
   {"challengePassword",1880096780,"AttributeType"},
   {0,1073741825,"pkcs-9"},
   {0,1,"7"},
-  {"Pkcs9challengePassword",536870930,0},
+  {"Pkcs9challengePassword",1610612754,0},
   {"printableString",1612709890,"PrintableString"},
   {"pkcs-9-ub-challengePassword",524298,"1"},
   {"utf8String",538968066,"UTF8String"},
   {"pkcs-9-ub-challengePassword",524298,"1"},
+  {"PrivateKeyInfo",1610612741,0},
+  {"version",1073741826,"Version"},
+  {"privateKeyAlgorithm",1073741826,"AlgorithmIdentifier"},
+  {"privateKey",1073741826,"PrivateKey"},
+  {"attributes",536895490,"Attributes"},
+  {0,4104,"0"},
+  {"Version",1610874883,0},
+  {"v1",1,"0"},
+  {"PrivateKey",1073741831,0},
+  {"Attributes",1610612751,0},
+  {0,2,"Attribute"},
+  {"EncryptedPrivateKeyInfo",1610612741,0},
+  {"encryptionAlgorithm",1073741826,"AlgorithmIdentifier"},
+  {"encryptedData",2,"EncryptedData"},
+  {"EncryptedData",1073741831,0},
+  {"pkcs-5",1879048204,0},
+  {"iso",1073741825,"1"},
+  {"member-body",1073741825,"2"},
+  {"us",1073741825,"840"},
+  {"rsadsi",1073741825,"113549"},
+  {"pkcs",1073741825,"1"},
+  {0,1,"5"},
+  {"pkcs-5-encryptionAlgorithm",1879048204,0},
+  {"iso",1073741825,"1"},
+  {"member-body",1073741825,"2"},
+  {"us",1073741825,"840"},
+  {"rsadsi",1073741825,"113549"},
+  {0,1,"3"},
+  {"pkcs-5-des-EDE3-CBC",1879048204,0},
+  {0,1073741825,"pkcs-5-encryptionAlgorithm"},
+  {0,1,"7"},
+  {"pkcs-5-des-EDE3-CBC-params",1612709895,0},
+  {0,1048586,"8"},
+  {"pkcs-5-id-PBES2",1879048204,0},
+  {0,1073741825,"pkcs-5"},
+  {0,1,"13"},
+  {"pkcs-5-PBES2-params",1610612741,0},
+  {"keyDerivationFunc",1073741826,"AlgorithmIdentifier"},
+  {"encryptionScheme",2,"AlgorithmIdentifier"},
+  {"pkcs-5-id-PBKDF2",1879048204,0},
+  {0,1073741825,"pkcs-5"},
+  {0,1,"12"},
+  {"pkcs-5-PBKDF2-params",536870917,0},
+  {"salt",1610612754,0},
+  {"specified",1073741831,0},
+  {"otherSource",2,"AlgorithmIdentifier"},
+  {"iterationCount",1611137027,0},
+  {"1",10,"MAX"},
+  {"keyLength",1611153411,0},
+  {"1",10,"MAX"},
+  {"prf",16386,"AlgorithmIdentifier"},
   {0,0,0}
 };
