@@ -30,56 +30,43 @@
 #include <common.h>
 
 typedef struct _oid2string {
-	const char * OID;
-	const char * DESC;
+	const char * oid;
 	const char * ldap_desc;
 	int choice;
 	int printable;
 } oid2string;
 
-#define PKIX1_RSA_OID "1.2.840.113549.1.1.1"
-#define DSA_OID "1.2.840.10040.4.1"
+/* This list contains all the OIDs that may be
+ * contained in a rdnSequence and are printable.
+ */
+static const oid2string _oid2str[] = {
+	{"2.5.4.6", "C", 0, 1},
+	{"2.5.4.12", "T", 1, 1},
+	{"2.5.4.10", "O", 1, 1},
+	{"2.5.4.11", "OU", 1, 1},
+	{"2.5.4.3", "CN", 1, 1},
+	{"2.5.4.7", "L", 1, 1},
+	{"2.5.4.8", "ST", 1, 1},
+	{"2.5.4.5", "serialNumber", 0, 1},
+	{"2.5.4.20", "telephoneNumber", 0, 1},
 
-#define DSA_SHA1_OID "1.2.840.10040.4.3"
-#define RSA_MD2_OID "1.2.840.113549.1.1.2"
-#define RSA_MD5_OID "1.2.840.113549.1.1.4"
-#define RSA_SHA1_OID "1.2.840.113549.1.1.5"
-
-static const oid2string OID2STR[] = {
-	{"2.5.4.6", "X520countryName", "C", 0, 1},
-	{"2.5.4.12", "X520title", "T", 1, 1},
-	{"2.5.4.10", "X520OrganizationName", "O", 1, 1},
-	{"2.5.4.11", "X520OrganizationalUnitName", "OU", 1, 1},
-	{"2.5.4.3", "X520CommonName", "CN", 1, 1},
-	{"2.5.4.7", "X520LocalityName", "L", 1, 1},
-	{"2.5.4.8", "X520StateOrProvinceName", "ST", 1, 1},
-	{"2.5.4.5", "X520serialNumber", "serialNumber", 0, 1},
-	{"2.5.4.20", "X520telephoneNumber", "telephoneNumber", 0, 1},
-
-	{"0.9.2342.19200300.100.1.25", "dc", "DC", 0, 1}, /* FIXME: CHOICE? */
-	{"0.9.2342.19200300.100.1.1", "uid", "UID", 0, 1}, /* FIXME: CHOICE? */
-	{"1.2.840.113549.1.9.1", "Pkcs9email", "EMAIL", 0, 1},
-	{"1.2.840.113549.1.9.7", "Pkcs9challengePassword", NULL, 1, 1},
-	{PKIX1_RSA_OID, "rsaEncryption", NULL, 0, 0},
-	{RSA_MD2_OID, "md2WithRSAEncryption", NULL, 0, 0},
-
-	{RSA_MD5_OID, "md5WithRSAEncryption", NULL, 0, 0},
-	{RSA_SHA1_OID, "sha1WithRSAEncryption", NULL, 0, 0},
-	{DSA_SHA1_OID, "id-dsa-with-sha1", NULL, 0, 0},
-	{DSA_OID, "id-dsa", NULL, 0, 0},
-	{NULL, NULL, NULL, 0, 0}
+	{"0.9.2342.19200300.100.1.25", "DC", 0, 1}, /* FIXME: CHOICE? */
+	{"0.9.2342.19200300.100.1.1", "UID", 0, 1}, /* FIXME: CHOICE? */
+	{"1.2.840.113549.1.9.1", "EMAIL", 0, 1},
+	{"1.2.840.113549.1.9.7", NULL, 1, 1},
+	{NULL, NULL, 0, 0}
 };
 
 /* Returns 1 if the data defined by the OID are printable.
  */
-int _gnutls_x509_oid_data_printable( const char* OID) {
+int _gnutls_x509_oid_data_printable( const char* oid) {
 int i = 0;
 
 	do {
-		if ( strcmp(OID2STR[i].OID, OID)==0)
-			return OID2STR[i].printable;
+		if ( strcmp(_oid2str[i].oid, oid)==0)
+			return _oid2str[i].printable;
 		i++;
-	} while( OID2STR[i].OID != NULL);
+	} while( _oid2str[i].oid != NULL);
 
 	return 0;
 }
@@ -87,38 +74,26 @@ int i = 0;
 /* Returns 1 if the data defined by the OID are of a choice
  * type.
  */
-int _gnutls_x509_oid_data_choice( const char* OID) {
+int _gnutls_x509_oid_data_choice( const char* oid) {
 int i = 0;
 
 	do {
-		if ( strcmp(OID2STR[i].OID, OID)==0)
-			return OID2STR[i].choice;
+		if ( strcmp(_oid2str[i].oid, oid)==0)
+			return _oid2str[i].choice;
 		i++;
-	} while( OID2STR[i].OID != NULL);
+	} while( _oid2str[i].oid != NULL);
 
 	return 0;
 }
 
-const char* _gnutls_x509_oid2string( const char* OID) {
+const char* _gnutls_x509_oid2ldap_string( const char* oid) {
 int i = 0;
 
 	do {
-		if ( strcmp(OID2STR[i].OID, OID)==0)
-			return OID2STR[i].DESC;
+		if ( strcmp(_oid2str[i].oid, oid)==0)
+			return _oid2str[i].ldap_desc;
 		i++;
-	} while( OID2STR[i].OID != NULL);
-
-	return NULL;
-}
-
-const char* _gnutls_x509_oid2ldap_string( const char* OID) {
-int i = 0;
-
-	do {
-		if ( strcmp(OID2STR[i].OID, OID)==0)
-			return OID2STR[i].ldap_desc;
-		i++;
-	} while( OID2STR[i].OID != NULL);
+	} while( _oid2str[i].oid != NULL);
 
 	return NULL;
 }
@@ -129,7 +104,7 @@ int i = 0;
  * res may be null. This will just return the res_size, needed to
  * hold the string.
  */
-int _gnutls_x509_oid_data2string( const char* OID, void* value, 
+int _gnutls_x509_oid_data2string( const char* oid, void* value, 
 	int value_size, char * res, int *res_size) {
 
 int result;
@@ -146,13 +121,13 @@ ASN1_TYPE tmpasn = ASN1_TYPE_EMPTY;
 	
 	res[0] = 0;
 	
-	if ( _gnutls_x509_oid_data_printable( OID) == 0) {
+	if ( _gnutls_x509_oid_data_printable( oid) == 0) {
 		gnutls_assert();
 		return GNUTLS_E_INTERNAL_ERROR;
 	}
 
-	ANAME = _gnutls_x509_oid2string( OID);
-	CHOICE = _gnutls_x509_oid_data_choice( OID);
+	ANAME = asn1_find_structure_from_oid( _gnutls_get_pkix(), oid);
+	CHOICE = _gnutls_x509_oid_data_choice( oid);
 
 	if (ANAME==NULL) {
 		gnutls_assert();
@@ -236,6 +211,25 @@ gnutls_pk_algorithm _gnutls_x509_oid2pk_algorithm( const char* oid)
 	return GNUTLS_PK_UNKNOWN;
 }
 
+/* returns -1 on error
+ */
+gnutls_mac_algorithm _gnutls_x509_oid2mac_algorithm( const char* oid)
+{
+	if (strcmp( oid, OID_SHA1) == 0)
+		return GNUTLS_MAC_SHA;
+	else if (strcmp( oid, OID_MD5) == 0)
+		return GNUTLS_MAC_MD5;
+
+	return GNUTLS_MAC_UNKNOWN;
+}
+
+const char* _gnutls_x509_mac2oid( gnutls_mac_algorithm mac)
+{
+	if (mac == GNUTLS_MAC_SHA) return OID_SHA1;
+	else if (mac == GNUTLS_MAC_MD5) return OID_MD5;
+	else return NULL;
+}
+
 const char* _gnutls_x509_pk2oid( gnutls_pk_algorithm pk)
 {
 	if (pk == GNUTLS_PK_RSA) return PKIX1_RSA_OID;
@@ -248,7 +242,6 @@ const char* _gnutls_x509_sign2oid( gnutls_pk_algorithm pk, gnutls_mac_algorithm
 	if (pk == GNUTLS_PK_RSA) {
 		if (mac == GNUTLS_MAC_SHA) return RSA_SHA1_OID;
 		else if (mac == GNUTLS_MAC_MD5) return RSA_MD5_OID;
-		else if (mac == GNUTLS_MAC_MD2) return RSA_MD2_OID;
 	} else if (pk == GNUTLS_PK_DSA) {
 		if (mac == GNUTLS_MAC_SHA) return DSA_SHA1_OID;
 	}
