@@ -25,6 +25,7 @@
 #include <libtasn1.h>
 #include "common.h"
 #include "x509.h"
+#include <gnutls_num.h>
 #include "mpi.h"
 
 /*
@@ -102,7 +103,8 @@ int _gnutls_x509_read_dsa_params(opaque * der, int dersize, GNUTLS_MPI * params)
 	}
 
 	/* FIXME: If the parameters are not included in the certificate
-	 * then the issuer's parameters should be used.
+	 * then the issuer's parameters should be used. This is not
+	 * done yet.
 	 */
 
 	/* Read p */
@@ -309,6 +311,7 @@ int _gnutls_x509_write_rsa_params( GNUTLS_MPI * params, int params_size,
 		return result;
 	}
 
+	if (der == NULL) *dersize = 0;
 	result = asn1_der_coding( spk, "", der, dersize, NULL);
 
 	asn1_delete_structure(&spk);
@@ -321,3 +324,34 @@ int _gnutls_x509_write_rsa_params( GNUTLS_MPI * params, int params_size,
 	return 0;
 
 }
+
+/* this function reads a (small) unsigned integer
+ * from asn1 structs. Combines the read and the convertion
+ * steps.
+ */
+int _gnutls_x509_read_ui( ASN1_TYPE node, const char* value, 
+	opaque* tmpstr, int tmpstr_size, unsigned int* ret)
+{
+int len, result;
+
+	len = tmpstr_size;
+	result = asn1_read_value( node, value, tmpstr, &len);
+	if (result != ASN1_SUCCESS) {
+		return _gnutls_asn2err(result);
+	}
+
+	if (len == 1)
+		*ret = tmpstr[0];
+	else if (len == 2)
+		*ret = _gnutls_read_uint16(tmpstr);
+	else if (len == 3)
+		*ret = _gnutls_read_uint24(tmpstr);
+	else if (len == 4)
+		*ret = _gnutls_read_uint32(tmpstr);
+	else {
+		gnutls_assert();
+		return GNUTLS_E_UNIMPLEMENTED_FEATURE;
+	}
+
+	return 0;
+}
