@@ -35,6 +35,7 @@
 #include <dn.h>
 #include <x509.h>
 #include <mpi.h>
+#include <common.h>
 #include <verify.h>
 
 static int _gnutls_verify_certificate2(gnutls_x509_crt cert,
@@ -350,9 +351,6 @@ unsigned int _gnutls_x509_verify_certificate(gnutls_x509_crt * certificate_list,
 		status |= GNUTLS_CERT_NOT_TRUSTED;
 	}
 
-	/* FIXME: Check CRL --not done yet.
-	 */
-
 	return status;
 }
 
@@ -391,17 +389,9 @@ int len;
 		return _gnutls_asn2err(result);
 	}
 
-	*hash = (gnutls_mac_algorithm)-1;
-	
-	if ( strcmp(str, OID_MD5)==0) { /* MD5 */
-		*hash = GNUTLS_MAC_MD5;
-	} else if ( strcmp(str, OID_SHA1)==0) { /* SHA1 ID */
-		*hash = GNUTLS_MAC_SHA;
-	} else if ( strcmp(str, OID_MD2)==0) { /* MD2 */
-		*hash = GNUTLS_MAC_MD2;
-	}
+	*hash = _gnutls_x509_oid2mac_algorithm( str);
 
-	if (*hash==(gnutls_mac_algorithm)-1) {
+	if (*hash==GNUTLS_MAC_UNKNOWN) {
 
 		_gnutls_x509_log( "X509_SIG: HASH OID: %s\n", str);
 
