@@ -36,7 +36,7 @@
 #include <gnutls_ui.h>
 
 /**
-  * gnutls_x509_crt_init - This function initializes a gnutls_crl structure
+  * gnutls_x509_crt_init - This function initializes a gnutls_x509_crt structure
   * @cert: The structure to be initialized
   *
   * This function will initialize an X.509 certificate structure. 
@@ -61,6 +61,57 @@ int gnutls_x509_crt_init(gnutls_x509_crt * cert)
 	return GNUTLS_E_MEMORY_ERROR;
 }
 
+/*-
+  * _gnutls_x509_crt_cpy - This function copies a gnutls_x509_crt structure
+  * @dest: The structure where to copy
+  * @src: The structure to be copied
+  *
+  * This function will copy an X.509 certificate structure. 
+  *
+  * Returns 0 on success.
+  *
+  -*/
+int _gnutls_x509_crt_cpy(gnutls_x509_crt dest, gnutls_x509_crt src)
+{
+int ret;
+int der_size;
+opaque * der;
+gnutls_datum tmp;
+
+	ret = gnutls_x509_crt_export( src, GNUTLS_X509_FMT_DER, NULL, &der_size);
+	if (ret != GNUTLS_E_SHORT_MEMORY_BUFFER) {
+		gnutls_assert();
+		return ret;
+	}
+
+	der = gnutls_alloca( der_size);
+	if (der == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_MEMORY_ERROR;
+	}
+
+	ret = gnutls_x509_crt_export( src, GNUTLS_X509_FMT_DER, der, &der_size);
+	if (ret < 0) {
+		gnutls_assert();
+		gnutls_afree( der);
+		return ret;
+	}
+
+	tmp.data = der;
+	tmp.size = der_size;
+	ret = gnutls_x509_crt_import( dest, &tmp, GNUTLS_X509_FMT_DER);
+
+	gnutls_afree( der);
+
+	if (ret < 0) {
+		gnutls_assert();
+		return ret;
+	}
+
+	return 0;
+
+}
+
 /**
   * gnutls_x509_crt_deinit - This function deinitializes memory used by a gnutls_x509_crt structure
   * @cert: The structure to be initialized
@@ -582,7 +633,7 @@ int gnutls_x509_crt_get_subject_alt_name(gnutls_x509_crt cert,
 	if (result != ASN1_SUCCESS) {
 		/* couldn't decode DER */
 
-		_gnutls_log("X509 certificate: Decoding error %d\n", result);
+		_gnutls_x509_log("X509 certificate: Decoding error %d\n", result);
 		gnutls_assert();
 		asn1_delete_structure(&c2);
 		return _gnutls_asn2err(result);
@@ -978,8 +1029,8 @@ int gnutls_x509_crt_get_fingerprint(gnutls_x509_crt cert,
 	gnutls_digest_algorithm algo, char *buf,
 	 int *sizeof_buf)
 {
-opaque cert_buf[MAX_X509_CERT_SIZE];
-int cert_buf_size = sizeof( cert_buf);
+opaque *cert_buf;
+int cert_buf_size;
 int result;
 gnutls_datum tmp;
 
@@ -987,18 +1038,56 @@ gnutls_datum tmp;
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
+	cert_buf_size = 0;
+	asn1_der_coding( cert->cert, "", NULL, &cert_buf_size, NULL);
+
+	cert_buf = gnutls_alloca( cert_buf_size);
+	if (cert_buf == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_MEMORY_ERROR;
+	}
+
 	result = asn1_der_coding( cert->cert, "",
 		cert_buf, &cert_buf_size, NULL);
 	
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
+		gnutls_afree( cert_buf);
 		return _gnutls_asn2err(result);
 	}
 	
-	tmp.data = cert_buf;
 	tmp.size = cert_buf_size;
 
-	return gnutls_fingerprint( algo, &tmp, buf, sizeof_buf);
+	result = gnutls_fingerprint( algo, &tmp, buf, sizeof_buf);
+	gnutls_afree( cert_buf);
+
+	return result;
+}
+
+/**
+  * gnutls_x509_crt_export - This function will export the certificate
+  * @cert: Holds the certificate
+  * @format: the format of output params. One of PEM or DER.
+  * @output_data: will contain a private key PEM or DER encoded
+  * @output_data_size: holds the size of output_data (and will be replaced by the actual size of parameters)
+  *
+  * This function will export the certificate to DER or PEM format.
+  *
+  * If the buffer provided is not long enough to hold the output, then
+  * GNUTLS_E_SHORT_MEMORY_BUFFER will be returned.
+  *
+  * If the structure is PEM encoded, it will have a header
+  * of "BEGIN CERTIFICATE".
+  *
+  * In case of failure a negative value will be returned, and
+  * 0 on success.
+  *
+  **/
+int gnutls_x509_crt_export( gnutls_x509_crt cert,
+	gnutls_x509_crt_fmt format, unsigned char* output_data, int* output_data_size)
+{
+	return _gnutls_x509_export_int( cert->cert, format, "CERTIFICATE", *output_data_size,
+		output_data, output_data_size);
 }
 
 
@@ -1010,21 +1099,23 @@ int _gnutls_x509_export_int( ASN1_TYPE asn1_data,
 	int tmp_buf_size, unsigned char* output_data, int* output_data_size)
 {
 	int result;
+	if (tmp_buf_size == 0) tmp_buf_size = 16*1024;
 	
 	if (format == GNUTLS_X509_FMT_DER) {
+		if (output_data == NULL) *output_data_size = 0;
+	
 		if ((result=asn1_der_coding( asn1_data, "", output_data, output_data_size, NULL)) != ASN1_SUCCESS) {
-			gnutls_assert();
-			
 			if (result == ASN1_MEM_ERROR)
 				return GNUTLS_E_SHORT_MEMORY_BUFFER;
 
+			gnutls_assert();
 			return _gnutls_asn2err(result);
 		}
 
 	} else { /* PEM */
 		opaque *tmp;
 		opaque *out;
-		int len = tmp_buf_size * 2 + 64;
+		int len = tmp_buf_size;
 		
 		tmp = gnutls_alloca( len);
 		if (tmp == NULL) {
